@@ -155,9 +155,7 @@
 //! ```
 //! # async_std::task::block_on(async {
 //! #
-//! use std::sync::Arc;
-//!
-//! use async_std::sync::Mutex;
+//! use async_std::sync::{Arc, Mutex};
 //! use async_std::task;
 //!
 //! let m1 = Arc::new(Mutex::new(0));
@@ -186,9 +184,11 @@ mod rwlock;
 
 cfg_unstable! {
     pub use barrier::{Barrier, BarrierWaitResult};
-    pub use channel::{channel, Sender, Receiver};
+    pub use channel::{channel, Sender, Receiver, RecvError, TryRecvError, TrySendError};
+    pub use condvar::Condvar;
 
     mod barrier;
+    mod condvar;
     mod channel;
 }
 
