@@ -3,21 +3,20 @@ use std::pin::Pin;
 use std::rc::Rc;
 use std::sync::Arc;
 
+use crate::prelude::*;
 use crate::stream::{self, FromStream, IntoStream};
 
 impl<T> FromStream<T> for Vec<T> {
     #[inline]
     fn from_stream<'a, S: IntoStream<Item = T>>(
         stream: S,
-    ) -> Pin<Box<dyn core::future::Future<Output = Self> + 'a>>
+    ) -> Pin<Box<dyn Future<Output = Self> + 'a>>
     where
         <S as IntoStream>::IntoStream: 'a,
     {
         let stream = stream.into_stream();
 
         Box::pin(async move {
-            pin_utils::pin_mut!(stream);
-
             let mut out = vec![];
             stream::extend(&mut out, stream).await;
             out
@@ -27,17 +26,12 @@ impl<T> FromStream<T> for Vec<T> {
 
 impl<'b, T: Clone> FromStream<T> for Cow<'b, [T]> {
     #[inline]
-    fn from_stream<'a, S: IntoStream<Item = T>>(
+    fn from_stream<'a, S: IntoStream<Item = T> + 'a>(
         stream: S,
-    ) -> Pin<Box<dyn core::future::Future<Output = Self> + 'a>>
-    where
-        <S as IntoStream>::IntoStream: 'a,
-    {
+    ) -> Pin<Box<dyn Future<Output = Self> + 'a>> {
         let stream = stream.into_stream();
 
         Box::pin(async move {
-            pin_utils::pin_mut!(stream);
-
             Cow::Owned(FromStream::from_stream(stream).await)
         })
     }
@@ -45,17 +39,12 @@ impl<'b, T: Clone> FromStream<T> for Cow<'b, [T]> {
 
 impl<T> FromStream<T> for Box<[T]> {
     #[inline]
-    fn from_stream<'a, S: IntoStream<Item = T>>(
+    fn from_stream<'a, S: IntoStream<Item = T> + 'a>(
         stream: S,
-    ) -> Pin<Box<dyn core::future::Future<Output = Self> + 'a>>
-    where
-        <S as IntoStream>::IntoStream: 'a,
-    {
+    ) -> Pin<Box<dyn Future<Output = Self> + 'a>> {
         let stream = stream.into_stream();
 
         Box::pin(async move {
-            pin_utils::pin_mut!(stream);
-
             Vec::from_stream(stream).await.into_boxed_slice()
         })
     }
@@ -63,17 +52,12 @@ impl<T> FromStream<T> for Box<[T]> {
 
 impl<T> FromStream<T> for Rc<[T]> {
     #[inline]
-    fn from_stream<'a, S: IntoStream<Item = T>>(
+    fn from_stream<'a, S: IntoStream<Item = T> + 'a>(
         stream: S,
-    ) -> Pin<Box<dyn core::future::Future<Output = Self> + 'a>>
-    where
-        <S as IntoStream>::IntoStream: 'a,
-    {
+    ) -> Pin<Box<dyn Future<Output = Self> + 'a>> {
         let stream = stream.into_stream();
 
         Box::pin(async move {
-            pin_utils::pin_mut!(stream);
-
             Vec::from_stream(stream).await.into()
         })
     }
@@ -81,17 +65,12 @@ impl<T> FromStream<T> for Rc<[T]> {
 
 impl<T> FromStream<T> for Arc<[T]> {
     #[inline]
-    fn from_stream<'a, S: IntoStream<Item = T>>(
+    fn from_stream<'a, S: IntoStream<Item = T> + 'a>(
         stream: S,
-    ) -> Pin<Box<dyn core::future::Future<Output = Self> + 'a>>
-    where
-        <S as IntoStream>::IntoStream: 'a,
-    {
+    ) -> Pin<Box<dyn Future<Output = Self> + 'a>> {
         let stream = stream.into_stream();
 
         Box::pin(async move {
-            pin_utils::pin_mut!(stream);
-
             Vec::from_stream(stream).await.into()
         })
     }
